cmoncrawl.aggregator.index\_query.IndexAggregator.get\_captured\_responses
==========================================================================

.. currentmodule:: cmoncrawl.aggregator.index_query

.. automethod:: IndexAggregator.get_captured_responses